@@ -32,9 +32,9 @@ class CircleObject(dict):
             raise AttributeError(e)
 
     @classmethod
-    def construct_from(cls, values, key):
-        instance = cls(values.get("id"), api_key=key)
-        instance.refresh_from(values, key)
+    def construct_from(cls, values, api_key):
+        instance = cls(values.get("id"), api_key=api_key)
+        instance.refresh_from(values, api_key)
         return instance
 
     def request(self, method, url, params=None, headers=None):
