@@ -1,12 +1,10 @@
 import circle
 from circle.circle_object import CircleObject
 import json
-from sns_message_validator import (
-    InvalidMessageTypeException,
+from sns_message_validator2 import (
     InvalidCertURLException,
     InvalidSignatureVersionException,
     SignatureVerificationFailureException,
-    SNSMessageType,
     SNSMessageValidator,
 )
 
