@@ -1,6 +1,8 @@
-from circle.resources.abstract import RetrievableAPIResource
-from circle.resources.abstract import ListableAPIResource
-from circle.resources.abstract import CreateableAPIResource
+from circle.resources.abstract import (
+    CreateableAPIResource,
+    ListableAPIResource,
+    RetrievableAPIResource
+)
 
 
 class Transfer(CreateableAPIResource, ListableAPIResource):
